Installation
------------

Source
~~~~~~

When installing from source, it is recommended (but not required) to
install Hubtty in a virtualenv.  To set one up::

  virtualenv hubtty-env
  source hubtty-env/bin/activate

To install the latest version from the cheeseshop::

  pip install hubtty

To install from a git checkout::

  pip install .
